@@ -26,9 +26,9 @@ def getRandomLineFromFile(path):
     content = getFileContent(path)
     return content[random.randint(0, len(content) - 1)]
 
-def appendToFile(path, text, nextLine=False):
+def appendToFile(path, text, nextLine=True):
     with open(path, 'a', encoding='utf-8') as file:
-        file.write(text + "\n" if nextLine else "")
+        file.write(text + ("\n" if nextLine else ""))
 
 def writeToFile(path, content):
     if type(content) is bytes:
